=======
History
=======

0.1.0 (2020-03-16)
------------------

* First release on PyPI.

0.1.1 
------------------
* Added learning aids such as tables and number lines

0.1.2 
------------------

* Added measurement type problem generators

0.2.0
------------------
* Added blocks to measurement problems for younger kids or to simply not use a ruler
* Added ability to easily generate multiple copies for multiple kids or usage over multiple days (see --numpages in gen_add_subtract) which I plan to extend to all problem generators


